BasicDataInterfaceApi class

Constructors

BasicDataInterfaceApi(RpcClient _client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkUsage(ClientContext? ctx, Empty request) → Future<ShioajiUsage>
createLongConnection(ClientContext? ctx, Empty request) → Future<Empty>
getAllFutureDetail(ClientContext? ctx, Empty request) → Future<FutureDetailResponse>
getAllOptionDetail(ClientContext? ctx, Empty request) → Future<OptionDetailResponse>
getAllStockDetail(ClientContext? ctx, Empty request) → Future<StockDetailResponse>
login(ClientContext? ctx, Empty request) → Future<Empty>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited